HlsPlayer class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- HlsPlayer
Constructors
-
HlsPlayer({Key? key, required String url, required Mode mode, int? startAt = 0, Map<
String, String> ? headers, bool autoplay = true, bool looping = false, Duration controlsHideTimeout = const Duration(seconds: 4), HlsControlsTheme? controlsTheme, WidgetBuilder? bufferingIndicatorBuilder, WidgetBuilder? placeholderBuilder, Widget controlsBuilder(BuildContext context, VideoController controller, bool isFullScreen, IQualities qualities, bool controlsVisible, void showControls(bool))?}) -
const
Properties
- autoplay → bool
-
final
- bufferingIndicatorBuilder → WidgetBuilder?
-
final
- controlsBuilder → Widget Function(BuildContext context, VideoController controller, bool isFullScreen, IQualities qualities, bool controlsVisible, void showControls(bool))?
-
final
- controlsHideTimeout → Duration
-
final
- controlsTheme → HlsControlsTheme?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> ? -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- looping → bool
-
final
- mode → Mode
-
final
- placeholderBuilder → WidgetBuilder?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startAt → int?
-
final
- url → String
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< HlsPlayer> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited